@@ -77,10 +77,14 @@ class LinkHeaderPagination(pagination.PageNumberPagination):
             ])
 
         headers = {
-            'Link': ", ".join(
-                [str(link) for link in link_parts]) if link_parts else {},
             'X-Total-Results': self.page.paginator.count,
+            'X-Page-Size': self.page_size,
+            'X-Page': self.page.number
         }
+
+        if link_parts:
+            headers['Link'] = ", ".join([str(link) for link in link_parts])
+
         return Response(data, headers=headers)
 
 
